@@ -159,6 +159,10 @@ class Connection(object):
     def close(self):
         self._transport.close()
 
+    def reopen(self):
+        self._transport.close()
+        self._transport.open()
+
     def commit(self):
         """Hive does not support transactions, so this does nothing."""
         pass
@@ -276,7 +280,16 @@ class Cursor(common.DBAPICursor):
         pass
 
     def _fetch_more(self):
-        return self.fetchall()
+        batch_size = self._arraysize
+        cursor.connection.reopen()
+        self._data = list()
+        for i in range(batch_size):
+            row = self.fetchone()
+            if row is None:
+                return
+            self._data.append(row)
+
+        return self._data
 
     def _fetch_all(self):
         self._data = list()
@@ -321,6 +334,8 @@ class Cursor(common.DBAPICursor):
         """
         pass
 
+    def reopen(self):
+        self.connection
 
 class Error(Exception):
     pass
@@ -341,7 +356,12 @@ if __name__ == '__main__':
                          thrift_transport=None)
     cursor = Cursor(connection)
     cursor.execute("select * from date_dim")
-    data = cursor.fetchall()
+    cursor.connection.reopen()
+    bdata = cursor._fetch_more()
+    while bdata:
+        print(len(bdata))
+        bdata = cursor._fetch_more()
+
 #
 # Type Objects and Constructors
 #
